# waves
Waves is a collection of general utilities and finite element tools for solving various PDE. The code is written in C++ interfaced in python through SWIG, and is developed at the University of Liège.

![](/dox/img.png)

## Features
Set of python/C++ modules:
  - [waves](/waves): 3D(Hex8) transient wave equation solver (FEM)
  - [flow](/flow): 2D(Tri3) and 3D(Tetra4) steady full potential equation solver (FEM)
  - [heat](/heat): 2D(Tri3) steady nonlinear heat equation solver (multiscale FE²M)
  - [mirrors](/mirrors): 3D(Hex8 and Tetra4) linear thermomechanical equations (FEM)
  - [katoptron](/katoptron): 3D(Hex8 and Tetra4) linear thermomechanical equations with contact (FEM)
  - [params](/params): parametric study
  - [tlnos](/tlnos): basic Trilinos examples

Additional features:
  - [x] [Gmsh](http://geuz.org/gmsh/) support for mesh and post-processing
  - [x] [VTK](http://www.vtk.org/)/[PyQt](https://riverbankcomputing.com/software/pyqt/intro) support for post processing and basic GUI
  - [x] [OpenBLAS](http://www.openblas.net/) or [Intel MKL](https://software.intel.com/en-us/intel-mkl) support
  - [x] [Eigen3](http://eigen.tuxfamily.org/index.php?title=Main_Page) support for linear algebra
     - [Intel Pardiso](https://software.intel.com/content/www/us/en/develop/documentation/mkl-developer-reference-c/top/sparse-solver-routines/intel-mkl-pardiso-parallel-direct-sparse-solver-interface/pardiso.html) support
     - [MUMPS](http://mumps.enseeiht.fr/) support
  - [x] [TBB](https://www.threadingbuildingblocks.org/) support for multithreading
  - [x] [mpi4py](https://bitbucket.org/mpi4py/mpi4py) support for parallelization
  - [x] [Trilinos](https://trilinos.github.io/) support (for some modules)

## Build

Detailed build instructions can be found in the [wiki](https://gitlab.uliege.be/am-dept/waves/wikis/home).

## References

Liegeois Kim, [GMRES with embedded ensemble propagation for the efficient solution of parametric linear systems in uncertainty quantification of computational models with application to the thermomechanical simulation of an ITER front mirror](http://hdl.handle.net/2268/249334), University of Liège, 2020.

Crovato Adrien, [Steady Transonic Aerodynamic and Aeroelastic Modeling for Preliminary Aircraft Design](http://hdl.handle.net/2268/251906), University of Liège, 2020.

Liegeois K., Boman R., Phipps E., Wiesner T., and Arnst M., [GMRES with embedded ensemble propagation for the efficient solution of parametric linear systems in uncertainty quantification of computational models](http://hdl.handle.net/2268/248201), Computer Methods in Applied Mechanics and Engineering, Vol. 369, 2020.

Crovato A., Boman R., Guner H., Terrapon V., Dimitriadis G., Almeida H., Prado A., Breviglieri C., Cabral P., and Silva, G., [A Full Potential Static Aeroelastic Solver for Preliminary Aircraft Design](http://hdl.handle.net/2268/237955), 18th International Forum on Aeroelasticity and Structural Dynamics, IFASD 2019.

Bilocq Amaury, [Implementation of a viscous-inviscid interaction scheme in a finite element full potential solver](http://hdl.handle.net/2268/252195), University of Liège, 2020.
