#!/usr/bin/env python3
# -*- coding: utf-8; -*-


from katoptron.eigenvalues import *
from katoptron.readers import *
import os
import fwk

import vtk
import tboxVtk
import tboxVtk.reader as vtkR
import tboxVtk.cutter as vtkC


def main():
    import matplotlib.pyplot as plt

    file_dir = os.path.dirname(__file__)
    work_dir = os.getcwd()

    display = False

    input_file_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_MG_beam_12/'

    filename_A_1 = input_file_dir + '1/Applied_Matrix_mm.txt'
    filename_A_2 = input_file_dir + '2/Applied_Matrix_mm.txt'
    filename_A_3 = input_file_dir + '3/Applied_Matrix_mm.txt'
    filename_A_4 = input_file_dir + '4/Applied_Matrix_mm.txt'
    filename_A_5 = input_file_dir + '5/Applied_Matrix_mm.txt'
    filename_A_6 = input_file_dir + '6/Applied_Matrix_mm.txt'

    filename_AQ_1 = input_file_dir + '1/Applied_Preconditioned_Matrix_mm.txt'
    filename_AQ_2 = input_file_dir + '2/Applied_Preconditioned_Matrix_mm.txt'
    filename_AQ_3 = input_file_dir + '3/Applied_Preconditioned_Matrix_mm.txt'
    filename_AQ_4 = input_file_dir + '4/Applied_Preconditioned_Matrix_mm.txt'
    filename_AQ_5 = input_file_dir + '5/Applied_Preconditioned_Matrix_mm.txt'
    filename_AQ_6 = input_file_dir + '6/Applied_Preconditioned_Matrix_mm.txt'

    filename_Q_1 = input_file_dir + '1/Applied_Preconditioner_mm.txt'
    filename_Q_2 = input_file_dir + '2/Applied_Preconditioner_mm.txt'
    filename_Q_3 = input_file_dir + '3/Applied_Preconditioner_mm.txt'
    filename_Q_4 = input_file_dir + '4/Applied_Preconditioner_mm.txt'
    filename_Q_5 = input_file_dir + '5/Applied_Preconditioner_mm.txt'
    filename_Q_6 = input_file_dir + '6/Applied_Preconditioner_mm.txt'

    filename_b = input_file_dir + '1/b_mm_after_bc.txt'

    b = read_mm(filename_b, is_sparse=False)

    Q_1 = read_mm(filename_Q_1, is_sparse=False)
    Q_2 = read_mm(filename_Q_2, is_sparse=False)
    Q_3 = read_mm(filename_Q_3, is_sparse=False)
    Q_4 = read_mm(filename_Q_4, is_sparse=False)
    Q_5 = read_mm(filename_Q_5, is_sparse=False)
    Q_6 = read_mm(filename_Q_6, is_sparse=False)

    b_1 = np.zeros((Q_1.shape[0],))
    b_2 = np.zeros((Q_2.shape[0],))
    b_3 = np.zeros((Q_3.shape[0],))
    b_4 = np.zeros((Q_4.shape[0],))
    b_5 = np.zeros((Q_5.shape[0],))
    b_6 = np.zeros((Q_6.shape[0],))

    b_1[0:len(b)] = b
    b_2[0:len(b)] = b
    b_3[0:len(b)] = b
    b_4[0:len(b)] = b
    b_5[0:len(b)] = b
    b_6[0:len(b)] = b

    x_1 = np.zeros((len(b_1),))
    x_2 = np.zeros((len(b_2),))
    x_3 = np.zeros((len(b_3),))
    x_4 = np.zeros((len(b_4),))
    x_5 = np.zeros((len(b_5),))
    x_6 = np.zeros((len(b_6),))

    A_1 = read_mm(filename_A_1, is_sparse=False)
    A_2 = read_mm(filename_A_2, is_sparse=False)
    A_3 = read_mm(filename_A_3, is_sparse=False)
    A_4 = read_mm(filename_A_4, is_sparse=False)
    A_5 = read_mm(filename_A_5, is_sparse=False)
    A_6 = read_mm(filename_A_6, is_sparse=False)

    r_1 = A_1.dot(x_1) - b_1
    r_2 = A_2.dot(x_2) - b_2
    r_3 = A_3.dot(x_3) - b_3
    r_4 = A_4.dot(x_4) - b_4
    r_5 = A_5.dot(x_5) - b_5
    r_6 = A_6.dot(x_6) - b_6

    AQ_1 = read_mm(filename_AQ_1, is_sparse=False)
    AQ_2 = read_mm(filename_AQ_2, is_sparse=False)
    AQ_3 = read_mm(filename_AQ_3, is_sparse=False)
    AQ_4 = read_mm(filename_AQ_4, is_sparse=False)
    AQ_5 = read_mm(filename_AQ_5, is_sparse=False)
    AQ_6 = read_mm(filename_AQ_6, is_sparse=False)

    plt.figure()
    plt.plot(Q_2.dot(r_2))
    plt.plot(Q_5.dot(r_5))
    plt.figure()
    tmp = Q_5.dot(r_5)
    tmp[0:len(r_2)] = tmp[0:len(r_2)] - Q_2.dot(r_2)
    plt.plot(tmp)
    # plt.plot(Q_2.dot(r_2))

    # plt.plot(Q_4.dot(r_4))
    # plt.figure()
    # plt.spy(A_1)
    # plt.figure()
    # plt.spy(A_3)
    plt.figure()
    plt.spy(Q_2, precision=1e-8)
    plt.figure()
    plt.spy(Q_5, precision=1e-8)
    plt.figure()
    tmp = Q_5
    tmp[0:252, 0:252] = tmp[0:252, 0:252] - Q_2
    plt.spy(tmp, precision=1e-8)

    plt.figure()
    tmp = A_5
    tmp[0:252, 0:252] = tmp[0:252, 0:252] - A_2
    plt.spy(tmp, precision=1e-8)

    tmp = np.abs(A_1.flatten())
    print(np.min(tmp[tmp != 0.]))
    tmp = np.abs(A_3.flatten())
    print(np.min(tmp[tmp != 0.]))

    plt.figure()
    tmp = AQ_5
    tmp[0:252, 0:252] = tmp[0:252, 0:252] - AQ_2
    plt.spy(tmp, precision=1e-8)
    plt.show()


if __name__ == "__main__":
    main()
