#ifndef KATOPTRON_GRAPH_H
#define KATOPTRON_GRAPH_H

#include "katoptron.h"

#include "Map.h"
#include "ElementsList.h"

#include <Tpetra_Map.hpp>
#include <Tpetra_Vector.hpp>
#include <Tpetra_CrsGraph.hpp>

#include <Teuchos_RCP.hpp>

namespace katoptron
{

/**
 * @brief Class used to compute and store the graph of the primal matrices with and without overlaps.
 */
class Graph
{
    typedef Map::local_ordinal_type local_ordinal_type;
    typedef Map::global_ordinal_type global_ordinal_type;
    typedef Tpetra::CrsGraph<local_ordinal_type, global_ordinal_type> crs_graph_type;

public:
    Teuchos::RCP<crs_graph_type> K;
    Teuchos::RCP<crs_graph_type> S;
    Teuchos::RCP<crs_graph_type> L;

    Graph(Teuchos::RCP<Map> map, Teuchos::RCP<ElementsList> elementsList);
};
}; // namespace katoptron

#endif //KATOPTRON_GRAPH_H
