/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WVTKEXPORT_KIM2CLEAN_H
#define WVTKEXPORT_KIM2CLEAN_H

#include "katoptron.h"
#include <string>
#include <memory>
#include <vector>
#include <map>

#ifndef SWIG

namespace tboxVtk
{

/**
 * @brief Save routines of Kim
 * @authors Kim Liegeois
 * @todo those functions have to be removed and wVtkExport has to be used instead.
 * However, there are currently two difficulties.
 *  - Each save_MPI function save on different meshes, a contact mesh has to be created and given to one of the
 *    VtkExport.
 *  - wVtkExport do not support MPI for now and some #ifdef VTK_HAS_MPI are currently unwanted in wVtkExport.
 *    At the end of the day, instead of using element[i]->no-1 it will be required to use a map to translate
 *    the global mesh id to local ones, those map will be trivial for one proc cases, and more complex when MPI
 *    is used. This will allow each proc to write only the data that it has computed. Moreover, Vtk MPI initialization
 *    and finalization will have to be used. Those can be done using some unwanted #ifdef VTK_HAS_MPI or using more
 *    elegant strategies or requiring VTK binaries that support MPI.
 */
class KATOPTRON_API VtkExport_KIM2CLEAN
{
public:
    std::shared_ptr<tbox::MshData> msh;

    VtkExport_KIM2CLEAN(std::shared_ptr<tbox::MshData> _msh);
    virtual ~VtkExport_KIM2CLEAN() {}

    void save_MPI(std::string const &fname,
                  tbox::Results const &r,
                  std::map<int, int> nodeWO_LO_to_GO,
                  std::map<int, int> nodeWO_GO_to_LO,
                  std::map<int, int> elements_GO_to_LO) const;
    void save_MPI(std::string const &fname,
                  tbox::Results const &r,
                  std::vector<int> contactElementID,
                  std::map<int, int> nodeWO_LO_to_GO,
                  std::map<int, int> nodeWO_GO_to_LO) const;
};

} // namespace tboxVtk

#endif

#endif //WVTKUTILS_KIMTOCLEAN_H
