#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2020 University of Liège
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.



import matplotlib as mpl
from mpl_toolkits.mplot3d import Axes3D
from matplotlib import cm
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.ticker import LinearLocator, FormatStrFormatter

def main():
    m = 20
    n = 20
    x, w = np.polynomial.legendre.leggauss(m)

    X = np.zeros((m,m))
    Y = np.zeros((m,m))
    phi_1 = np.zeros((m,m))

    Z_1 = np.zeros((m,n))
    Z_2 = np.zeros((m**2,n**2))

    for i in range(0,n):
        Z_1[:,i] = x**i

    X, Y = np.meshgrid(x, x)

    x_2 = X
    y_2 = Y

    x_2 = np.reshape(x_2,(m**2,))
    y_2 = np.reshape(y_2,(m**2,))


    for i in range(0,n):
        for j in range(0,n):
            Z_2[:,j+n*i] = x_2**i*y_2**j

    #for i in range(0,m):
    #    for j in range(0,m):
    #        phi_1[i,j] = X[i,j]**1*Y[i,j]**1

    U_1, s_1, V_1 = np.linalg.svd(Z_1, full_matrices=True)
    U_2, s_2, V_2 = np.linalg.svd(Z_2, full_matrices=True)

    plt.figure()

    plt.semilogy(list(range(1,n+1)),s_1**2,'ro')
    plt.semilogy(list(range(1,n**2+1)),s_2,'ko')
    for i in range(0,n):
        plt.semilogy([1,n**2+1],[s_1[i]**2,s_1[i]**2],'b')

    fig = plt.figure()
    ax = fig.gca(projection='3d')
    #for i in range(0,m):
    #    for j in range(0,m):
    #        ax.scatter(X[i,j], Y[i,j], phi_1[i,j],'*')

    Z_2V_2 = np.dot(Z_2,np.transpose(V_2))

    phi_1 = np.reshape(Z_2V_2[:,0],(m,m)) 
    phi_3 = np.reshape(Z_2V_2[:,2],(m,m)) 
    phi_5 = np.reshape(Z_2V_2[:,4],(m,m)) 

    surf = ax.plot_surface(X, Y, phi_1, rstride=1, cstride=1, cmap=cm.jet,
                       linewidth=0, antialiased=False)
    surf = ax.plot_surface(X, Y, phi_3, rstride=1, cstride=1, cmap=cm.jet,
                       linewidth=0, antialiased=False)
    surf = ax.plot_surface(X, Y, phi_5, rstride=1, cstride=1, cmap=cm.jet,
                       linewidth=0, antialiased=False)
    
    ax.axis('equal')
    plt.show()

if __name__ == "__main__":
    main()
