/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// SWIG input file of the 'waves' module

%feature("autodoc","1");

%module(docstring=
"'wavesw' module: projet MP 2014
(c) ULg - A&M",
directors="1",
threads="1"
) wavesw
%{

#include <string>
#include <sstream>
#include "waves.h"

#include "fwkw.h"
#include "tboxw.h"

#include "wForwardEuler.h"
#include "wRungeKutta.h"
#include "wTimeIntegration.h"
#include "wProblem.h"
#include "wNewmark.h"
#include "wSource.h"
#include "wMedium.h"
#include "wBoundary.h"

#include "wDisplayHook.h"

%}

%include "fwkw.swg"

// ----------- MODULES UTILISES ------------
%import "fwkw.i"
%import "tboxw.i"

// ----------- WAVES CLASSES ---------------
%include "waves.h"

%shared_ptr(waves::Problem);
%shared_ptr(waves::Source);
%shared_ptr(waves::Medium);
%shared_ptr(waves::Boundary);


%feature("director") DisplayHook;
%include "wDisplayHook.h"

%feature("director:except") {
    if ($error != NULL) {
        std::cout << "[in director:except]\n";
        //throw Swig::DirectorMethodException();
        throw std::runtime_error("Director problem");
    }
}

%feature("director") waves::Source;
%pythonappend waves::Source::Source "self.__disown__()"    // for directors
%include "wSource.h"

%include "wMedium.h"
%include "wBoundary.h"

%immutable waves::Problem::msh; // avoids the creation of the setter method
%include "wProblem.h"

%include "wTimeIntegration.h"
%include "wForwardEuler.h"
%include "wRungeKutta.h"
%include "wNewmark.h"

